data(GiaeverPheno)
data(GiaeverGene)
data(GiaeverExpCdt)GiaeverPheno is a list with 31 elements. The name of each
element is a experimental condition (see details). The value of each
element are the fitness defect scores for the genes sensitive to the
experimental condition, as defined by Giaever et al (2002). GiaeverGene Vector of the systematic gene names of the 5898 tested
genes. Note that some updates have been made for the list to be
consistent with Saccharomyces Genome Database. GiaeverExpCdt is a 3 columns dataframe with fileID from
which the data were extracted, the generation time (growth time) and
the condition (media). Giaeverresult is a data.frame that summaryzes the number of
sensitive genes per condition, how many of those genes are present in
the ScISI interactome and the associated p-value. This is the result
of applying a Hypergeometric test (see CoHyperGParams-class
for more details) and the complexStatus function. data(GiaeverPheno)
data(GiaeverExpCdt)
data(GiaeverGene)
Run the code above in your browser using DataLab