Learn R Programming

PCpheno (version 1.28.0)

KEGG2SCISI: Mapping between KEGG and ScISI

Description

Count the number of genes shared between a KEGG pathway and a protein complex from the ScISI interactome.

Usage

KEGG2SCISI(pw, pc, pcMat, pwMat)

Arguments

pw
list of pathway names
pc
list of complex names
pwMat
pathway incidence matrix
pcMat
complex incidence matrix

Value

matrix

See Also

ScISI KEGG

Examples

Run this code
data(ScISIC)
## Mapping from Yeast genes to KEGG pathways.
KeggMat <- PWAmat("org.Sc.sgd")
KEGG2SCISI(pw = colnames(KeggMat)[1:5], pc = colnames(ScISIC)[1:5], pwMat =
KeggMat, pcMat =ScISIC)

Run the code above in your browser using DataLab