Learn R Programming

PCpheno (version 1.28.0)

OsterbergRaw: Data from Osterberg at al. 2006

Description

Osterberg at al. (2006) report growth phenotypes in yeast for a strain collection over-expression ~600 C-terminal tagged integral membrane proteins growth both under normal and three different stress conditions.

Usage

data(OsterbergRaw)

Arguments

Format

OsterbergRaw is a 17 columns dataframe.
SYSTEMATIC
Systematic gene names of the studied membrane protein
COMMUN
Commun gene names of the studied membrane protein
TMHMM.C
The topology predicted by TMHMM (TransMembrane prediction using Hidden Markov Models) using the experimentally assigned C-terminal location for the protein as a constraint. The topology is represented in the format Location of N-terminus TMhelices Location of C-terminus (i and o stand for in and out respectively)
WesternBlot
Protein expression levels (arbitrary units), estimated from the band intensity and normalized to the internal standard on each Western blot.
Bands
Proteins detected as two distinct bands with different molecular mass on the Western blot analysis. category 1 indicates that both bands were insensitive to Endo H digestion, 2 indicates the higher molecular mass was shifted down upon Endo H digestion on SDS/PAGE and one band was predominant compared to the other, and 3 indicates that a higher molecular mass band shifted down upon Endo H digestion on SDS/PAGE and both bands were equal intensity on Western blot
Toxicity
Toxicity index from Spoko et al. (2006). The index varies between 1 and 5, where 1 means the strain is dead, and 5 indicates no difference in growth rate compared with the wild type strain.
sign.norm
Over-expression strains that show a significant (P<0.001) growth="" rate="" phenotype="" (lscrate)="" in="" synthetic="" defined="" medium="" conditions="" (warringer="" et="" al.,="" 2003).="" an="" average="" of="" two="" replicates="" is="" given.="" strains="" that="" do="" not="" show="" a="" significant="" difference="" doubling="" time="" compared="" with="" the="" wild-type="" strain="" are="" indicated="" by="" 0.<="" dd="">
all.norm
Phenotypes (significant or not) of over-expression strains (LSCrate) in synthetic defined medium conditions (Warringer et al., 2003). An average of two replicates is given.
sign.NaCl
Over-expression strains that show a significant (P<0.001) growth="" rate="" phenotype="" (lpirate)="" in="" nacl.="" an="" average="" of="" two="" replicates="" is="" given.="" strains="" that="" do="" not="" show="" a="" significant="" difference="" doubling="" time="" compared="" with="" the="" wild-type="" strain="" under="" nacl="" stress="" are="" indicated="" by="" 0.<="" dd="">
all.NaCl.LSC
Phenotypes (significant or not) of over-expression strains (LSCrate) in NaCl (Warringer et al., 2003). An average of two replicates is given.
all.NaCl.LPI
Phenotypes (significant or not) of over-expression strains (LPIrate) in NaCl (Warringer et al., 2003). An average of two replicates is given.
sign.caff
Over-expression strains that show a significant (P<0.001) growth="" rate="" phenotype="" (lpirate)="" in="" caffeine.="" an="" average="" of="" two="" replicates="" is="" given.="" strains="" that="" do="" not="" show="" a="" significant="" difference="" doubling="" time="" compared="" with="" the="" wild-type="" strain="" under="" caffeine="" stress="" are="" indicated="" by="" 0.<="" dd="">
all.caff.LSC
Phenotypes (significant or not) of over-expression strains (LSCrate) in caffeine (Warringer et al., 2003). An average of two replicates is given
all.caff.LPI
Phenotypes (significant or not) of over-expression strains (LPIrate) in caffeine (Warringer et al., 2003). An average of two replicates is given.
sign.paraq.
Over-expression strains that show a significant (P<0.001) growth="" rate="" phenotype="" (lpirate)="" in="" paraquat.="" an="" average="" of="" two="" replicates="" is="" given.="" strains="" that="" do="" not="" show="" a="" significant="" difference="" doubling="" time="" compared="" with="" the="" wild-type="" strain="" under="" paraquat="" stress="" are="" indicated="" by="" 0.<="" dd="">
all.paraq.LSC
Phenotypes (significant or not) of overexpression strains (LSCrate) in paraquat (Warringer et al., 2003). An average of two replicates is given.
all.paraq.LPI
Phenotypes (significant or not) of overexpression strains (LPIrate) in paraquat (Warringer et al., 2003). An average of two replicates is given.

References

Osterberg M, Kim H, Warringer J, Melen K, Blomberg A, von Heijne G. (2006) Phenotypic effects of membrane protein overexpression in Saccharomyces cerevisiae. PNAS. 103(30):11148-53. PMID: 16847257

Examples

Run this code
data(OsterbergRaw)
str(OsterbergRaw)

Run the code above in your browser using DataLab