Learn R Programming

PCpheno (version 1.34.0)

SGDphenoL: Saccharomyces Genome Database list of phenotypic data

Description

Saccharomyces Genome Database list of phenotypes and associated genes from several published experiments (last update 2006).

Usage

data(SGDphenoL)

Arguments

Format

SGDphenoL is a list of phenotypes. Under each phenotype is listed the genes that potentially induce that phenotype. A binary matrix can be built from that list using the list2Matrix function from the Rintact package.

SGD, supplementary information: http://www.yeastgenome.org/

Examples

Run this code
data(SGDphenoL)

Run the code above in your browser using DataLab