SGDphenoL: Saccharomyces Genome Database list of phenotypic data
Description
Saccharomyces Genome Database list of phenotypes
and associated genes from several published experiments (last update 2006).
Format
SGDphenoL is a list of phenotypes. Under each
phenotype is listed the genes that potentially induce that
phenotype. A binary matrix can be built from that list using the
list2Matrix function from the Rintact package.